# CGODME
This experimental version aims to find optimal path flows by systematically mapping variables (zonal totals, origin-destination demand, and link flows).

## Quick Start
Users can find [Jupyter notebook](https://github.com/Taehooie/CGODME/blob/develop/tutorial/tutorial.ipynb) that provides step-by-step instructions for utilization. 

## Installation
cgodme has been published on [PyPI](https://pypi.org/project/cgodme/) and can be installed using
```
$ pip install cgodme
```

## How to Cite
- Journal article: [Kim, T., et al. Computational graph-based mathematical programming reformulation for integrated demand and supply models](https://www.sciencedirect.com/science/article/abs/pii/S0968090X2400192X)

